Type: Package
Package: iotarelr
Title: Iota Inter Coder Reliability for Content Analysis
Version: 0.1.9
Authors@R: c(
    person("Berding", "Florian", , "florian.berding@uni-hamburg.de", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-3593-1695")),
    person("Pargmann", "Julia", , "julia.pargmann@uni-hamburg.de", role = "ctb",
           comment = c(ORCID = "0000-0003-3616-0172"))
  )
Description: Routines and tools for assessing the quality of content
    analysis on the basis of the Iota Reliability Concept. The concept is
    inspired by item response theory and can be applied to any kind of
    content analysis which uses a standardized coding scheme and discrete
    categories.  It is also applicable for content analysis conducted by
    artificial intelligence.  The package provides reliability measures
    for a complete scale as well as for every single category. Analysis of
    subgroup-invariance and error corrections are implemented. This
    information can support the development process of a coding scheme and
    allows a detailed inspection of the quality of the generated data.
    Equations and formulas working in this package are part of Berding et
    al. (2022)<doi:10.3389/feduc.2022.818365> and Berding and Pargmann
    (2022) <doi:10.30819/5581>.
License: GPL-3
URL: https://fberding.github.io/iotarelr/
BugReports: https://github.com/FBerding/iotarelr/issues
Depends: R (>= 3.5.0)
Imports: ggalluvial, ggplot2, gridExtra, methods, Rcpp, rlang, stats
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
LinkingTo: Rcpp
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2026-05-07 08:36:33 UTC; WissMit
Author: Berding Florian [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3593-1695>),
  Pargmann Julia [ctb] (ORCID: <https://orcid.org/0000-0003-3616-0172>)
Maintainer: Berding Florian <florian.berding@uni-hamburg.de>
Repository: CRAN
Date/Publication: 2026-05-07 12:40:34 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-07 14:20:51 UTC; unix
Archs: iotarelr.so.dSYM
