# Generated by roxygen2: do not edit by hand

export(EM_algo_c)
export(check_conformity_c)
export(check_dgf)
export(check_new_rater)
export(compute_iota1)
export(compute_iota2)
export(est_con_multinominal_c)
export(est_expected_categories)
export(get_consequences)
export(get_iota2_measures)
export(get_patterns)
export(get_summary)
export(plot_iota)
export(plot_iota2_alluvial)
import(ggalluvial)
import(ggplot2)
importFrom(Rcpp,sourceCpp)
importFrom(methods,is)
importFrom(rlang,.data)
useDynLib(iotarelr)
