# This file is part of the R package "iotarelr".
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3 as published by
# the Free Software Foundation.
#
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>

#' Example Data Set
#'
#' A data set containing the ratings of three coders for written exams.
#' It also contains the gender of the people who took the exam. The data
#' is not real and is only created for illustrating purposes.
#' @docType data
#' @format A data frame with 318 rows and 4 variables:
#' \describe{
#'   \item{Coder A}{Ratings of coder A.}
#'   \item{Coder B}{Ratings of coder B.}
#'   \item{Coder C}{Ratings of coder C.}
#'   \item{Sex}{Referring to the biological aspects of an individual.}
#' }
"iotarelr_written_exams"
